Summary:          A TCP/HTTP reverse proxy for high availability environments
Name:             haproxy
Version:          1.7.6
Release:          1%{?dist}%{?pext}
License:          GPLv2+
Group:            System Environment/Daemons
Source0:          http://www.%{name}.org/download/1.7/src/%{name}-%{version}.tar.gz
Source1:          %{name}.init
Source2:          %{name}.sysconfig
Source3:          %{name}.logrotate
Source4:          %{name}.conf
Patch0:           %{name}-1.7.6-build_lua.patch
Patch1:           %{name}-1.5.14-contrib_halog.patch
URL:              http://www.%{name}.org/
Buildroot:        %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Vendor:           Willy Tarreau <w@1wt.eu>
Requires(pre):    /usr/sbin/groupadd /usr/sbin/useradd
Requires(post):   /sbin/chkconfig
Requires(preun):  /sbin/chkconfig /sbin/service
Requires(postun): /sbin/service
BuildRequires:    lua53-devel openssl10-devel pcre-devel
BuildRequires:    zlib-devel
BuildArch:        i486 x86_64


%description
HAProxy is a free, very fast and reliable solution offering high availability,
load balancing, and proxying for TCP and HTTP-based applications. It is parti-
cularly suited for very high traffic web sites and powers quite a number of the
world's most visited ones. Over the years it has become the de-facto standard
open-source load balancer, is now shipped with most mainstream distributions,
and is often deployed by default in cloud platforms.


%prep
%setup -q
%patch0 -p1
%patch1 -p1


%build
%{__make} %{?_smp_mflags}           \
	CC="%{__cc}"                \
	ADDINC="${RPM_OPT_FLAGS}"   \
	CPU="generic"               \
	TARGET="linux26"            \
	USE_GETADDRINFO=1           \
	USE_LINUX_TPROXY=1          \
%ifarch %ix86 x86_64
	USE_REGPARM=1               \
%endif
	USE_LUA=1                   \
	USE_PCRE=1                  \
	USE_OPENSSL=1               \
	USE_ZLIB=1

for TOOL in halog iprange ip6range; do
  pushd contrib/${TOOL}
  %{__make} %{?_smp_mflags}         \
	OPTIMIZE="${RPM_OPT_FLAGS}" \
	${TOOL}
  popd
done


%install
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_initrddir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_sysconfdir}/{logrotate.d,sysconfig,%{name}}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_bindir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_datadir}/%{name}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/lib/%{name}

%{__make} \
	DESTDIR=${RPM_BUILD_ROOT} \
	PREFIX=%{_prefix}         \
	install-bin install-man

%{__install} -m 0755 %{SOURCE1}   ${RPM_BUILD_ROOT}%{_initrddir}/%{name}
%{__install} -m 0644 %{SOURCE2}   ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig/%{name}
%{__install} -m 0644 %{SOURCE3}   ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d/%{name}

%{__install} -m 0640 %{SOURCE4}   ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/%{name}.cfg

for TOOL in halog iprange ip6range; do
  pushd contrib/${TOOL}
  %{__install} -m 0755 ${TOOL}    ${RPM_BUILD_ROOT}%{_bindir}
  %{__install} -m 0644 ${TOOL}.1  ${RPM_BUILD_ROOT}%{_mandir}/man1 2>/dev/null || :
  popd
done

pushd examples
%{__install} -m 0644 errorfiles/* ${RPM_BUILD_ROOT}%{_datadir}/%{name}
popd

# Cleanup
%{__rm}      -f                   ${RPM_BUILD_ROOT}%{_sbindir}/%{name}-systemd-wrapper


%pre
if ! getent group  %{name} >/dev/null 2>&1; then
  /usr/sbin/groupadd -r -g 188 %{name}
fi
if ! getent passwd %{name} >/dev/null 2>&1; then
  /usr/sbin/useradd  -r -u 188 -g %{name} \
	-d %{_localstatedir}/lib/%{name}  \
	-c "HAProxy Service user" -M      \
	-s /sbin/nologin %{name}
fi
exit 0			# Always pass


%post
/sbin/chkconfig --add %{name}


%preun
if [ $1 -eq 0 ]; then	# Remove
  /sbin/service %{name} stop >/dev/null 2>&1
  /sbin/chkconfig --del %{name}
fi


%postun
if [ $1 -ge 1 ]; then	# Upgrade
  /sbin/service %{name} condrestart >/dev/null 2>&1 || :
fi


%clean
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc CHANGELOG CONTRIBUTING LICENSE MAINTAINERS
%doc README ROADMAP doc/*.{fig,txt}
%doc --parents examples/*.{cfg,sh,vim}
%attr(750,root,%{name}) %dir %{_sysconfdir}/%{name}
%attr(640,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}/%{name}.cfg
%{_initrddir}/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_bindir}/halog
%{_bindir}/iprange
%{_bindir}/ip6range
%{_sbindir}/%{name}
%config(noreplace) %{_datadir}/%{name}
%{_mandir}/man1/*.1*
%attr(750,%{name},%{name}) %dir %{_localstatedir}/lib/%{name}


%changelog
* Sun Jun 25 2017 Peter Pramberger <peterpramb@member.fsf.org> - 1.7.6-1
- New version (1.7.6)

* Sun Jun 04 2017 Peter Pramberger <peterpramb@member.fsf.org> - 1.7.5-1
- New version (1.7.5)

* Mon Mar 06 2017 Peter Pramberger <peterpramb@member.fsf.org> - 1.7.3-1
- New version (1.7.3)

* Wed Feb 15 2017 Peter Pramberger <peterpramb@member.fsf.org> - 1.7.2-1
- New version (1.7.2)

* Thu Jan 12 2017 Peter Pramberger <peterpramb@member.fsf.org> - 1.7.1-1
- New version (1.7.1)

* Mon Nov 21 2016 Peter Pramberger <peterpramb@member.fsf.org> - 1.6.10-1
- New version (1.6.10)

* Wed Sep 21 2016 Peter Pramberger <peterpramb@member.fsf.org> - 1.6.9-1
- New version (1.6.9)

* Mon May 09 2016 Peter Pramberger <peterpramb@member.fsf.org> - 1.6.4-1
- New version (1.6.4)

* Sat Jan 02 2016 Peter Pramberger <peterpramb@member.fsf.org> - 1.6.3-1
- New version (1.6.3)

* Sun Nov 15 2015 Peter Pramberger <peterpramb@member.fsf.org> - 1.6.2-1
- New version (1.6.2)

* Sat Jul 25 2015 Peter Pramberger <peterpramb@member.fsf.org> - 1.5.14-1
- Initial build
